from .uberagent import uberagent, uberagent600, uberagent610, uberagent620, uberagent700, uberagent710, uberagent720, uberagent730, uberagent740, uberagent_develop

pipelines = {
    "uberagent": uberagent,
    "uberagent-6.0.0": uberagent600,
    "uberagent-6.1.0": uberagent610,
    "uberagent-6.2.0": uberagent620,
    "uberagent-7.0.0": uberagent700,
    "uberagent-7.1.0": uberagent710,
    "uberagent-7.2.0": uberagent720,
    "uberagent-7.3.0": uberagent730,
    "uberagent-7.4.0": uberagent740,
    "uberagent-develop": uberagent_develop
}
